==> push-0.13.0-sources.jar: com/flybits/android/push/services/FlybitsPushService.java <==
package com.flybits.android.push.services;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.NotificationCompat;
import android.support.v4.content.LocalBroadcastManager;
import android.text.TextUtils;

import com.flybits.android.push.PushManager;
import com.flybits.android.push.R;
import com.flybits.android.push.exceptions.FlybitsPushException;
import com.flybits.android.push.models.Push;
import com.flybits.commons.library.api.results.callbacks.ObjectResultCallback;
import com.flybits.commons.library.exceptions.FlybitsException;
import com.flybits.commons.library.logging.Logger;
import com.google.firebase.messaging.FirebaseMessagingService;
import com.google.firebase.messaging.RemoteMessage;

import java.util.Map;

import static com.flybits.android.push.FlyingPushConstants.ACTION_PUSH_RECEIVED_FCM;
import static com.flybits.android.push.FlyingPushConstants.ACTION_PUSH_RECEIVED_FLYBITS;
import static com.flybits.android.push.FlyingPushConstants.EXTRA_PUSH_NOTIFICATION;

public class FlybitsPushService extends FirebaseMessagingService {

    private final String _TAG = "FlybitsFirebaseReceiver";
    private final String NOTIFICATION_CHANNEL_FLYBITS = "com.flybits.push.channel.generic";

    @Override
    public void onMessageReceived(final RemoteMessage message){

        Logger.setTag(_TAG).i("FlybitsFCMReceiver->Received Message: " + message.getData());
        Map data = message.getData();
        PushManager.parsePushNotification(getBaseContext(), data, new ObjectResultCallback<Push>() {
            @Override
            public void onSuccess(Push push) {
                Logger.setTag(_TAG).i("Received Flybits Push: " + push.toString());
                setNotification(getBaseContext(), push.getTitle(), push.getMessage());

                Intent intentCustom = new Intent(ACTION_PUSH_RECEIVED_FLYBITS);
                intentCustom.putExtra(ACTION_PUSH_RECEIVED_FLYBITS, push);
                LocalBroadcastManager.getInstance(getBaseContext()).sendBroadcast(intentCustom);
            }

            @Override
            public void onException(FlybitsException e) {
                if (e instanceof FlybitsPushException) {
                    if (message.getNotification() != null) {
                        Logger.setTag(_TAG).i("Received FCM Push: " + message.getNotification().getBody());
                        setNotification(getBaseContext(), message.getNotification().getTitle(), message.getNotification().getBody());
                    }

                    Intent intentCustom = new Intent(ACTION_PUSH_RECEIVED_FCM);
                    intentCustom.putExtra(EXTRA_PUSH_NOTIFICATION, message);
                    LocalBroadcastManager.getInstance(getBaseContext()).sendBroadcast(intentCustom);
                }
            }
        });
    }

    private void setNotification(Context context, String title, String body){
        NotificationManager mNotificationManager = (NotificationManager)
                context.getSystemService(Context.NOTIFICATION_SERVICE);

        boolean isTitlePresent = !TextUtils.isEmpty(title);
        //Incase null to avoid crash
        if (body == null) {
            body = "";
        }

        long[] vibration = new long[1];
        vibration[0] = 100L;

        NotificationCompat.BigTextStyle bigText = new NotificationCompat.BigTextStyle();
        bigText.bigText(body);

        String txtTitle = (isTitlePresent) ? title : "Received Notification";
        bigText.setBigContentTitle(txtTitle);

        NotificationCompat.Builder mBuilder =
                new NotificationCompat.Builder(context, NOTIFICATION_CHANNEL_FLYBITS)
                        .setContentText(body)
                        .setSmallIcon(getResource())
                        .setVibrate(vibration)
                        .setStyle(bigText)
                        .setWhen(System.currentTimeMillis())
                        .setShowWhen(true)
                        .setAutoCancel(true);

        if (isTitlePresent) {
            mBuilder.setContentTitle(txtTitle);
        }

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            NotificationChannel mChannel = new NotificationChannel(NOTIFICATION_CHANNEL_FLYBITS, "RBC Cross-Border",
                    NotificationManager.IMPORTANCE_DEFAULT);

            // Configure the notification channel.
            mChannel.enableLights(true);
            mChannel.enableVibration(true);
            mNotificationManager.createNotificationChannel(mChannel);
        }

        int num = (int) System.currentTimeMillis();
        mNotificationManager.notify(num, mBuilder.build());
    }

    private int getResource(){
        try {
            ComponentName myService = new ComponentName(this, this.getClass());
            Bundle bundle = getPackageManager().getServiceInfo(myService, PackageManager.GET_META_DATA).metaData;

            if (bundle.containsKey("com.flybits.push.notification.icon")) {
                return  bundle.getInt("com.flybits.push.notification.icon");
            }
        }catch (PackageManager.NameNotFoundException | NullPointerException e) {
            Logger.exception("FlybitsPushService.getResource", e);
        }
        Logger.setTag(_TAG).w("It appears that you have not set your icon's resource field within your AndroidManifest declaration of the FlybitsPushService. Please visit https://devportal.flybits.com/#/documentation/android/push/push-notifications-receiving for more details.");
        return R.mipmap.ic_flybits_notification;
    }
}

==> push-0.14.0-sources.jar: com/flybits/android/push/services/FlybitsPushService.java <==
package com.flybits.android.push.services;

import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.NotificationCompat;
import android.support.v4.content.LocalBroadcastManager;
import android.text.TextUtils;

import com.flybits.android.push.PushManager;
import com.flybits.android.push.R;
import com.flybits.android.push.exceptions.FlybitsPushException;
import com.flybits.android.push.models.Push;
import com.flybits.commons.library.api.results.callbacks.ObjectResultCallback;
import com.flybits.commons.library.exceptions.FlybitsException;
import com.flybits.commons.library.logging.Logger;
import com.google.firebase.messaging.FirebaseMessagingService;
import com.google.firebase.messaging.RemoteMessage;

import java.util.Map;

import static com.flybits.android.push.FlyingPushConstants.ACTION_PUSH_RECEIVED_FCM;
import static com.flybits.android.push.FlyingPushConstants.ACTION_PUSH_RECEIVED_FLYBITS;
import static com.flybits.android.push.FlyingPushConstants.EXTRA_PUSH_NOTIFICATION;

public class FlybitsPushService extends FirebaseMessagingService {

    private final String _TAG = "FlybitsFirebaseReceiver";
    private final String NOTIFICATION_CHANNEL_FLYBITS = "com.flybits.push.channel.generic";

    @Override
    public void onMessageReceived(final RemoteMessage message){

        Logger.setTag(_TAG).i("FlybitsFCMReceiver->Received Message: " + message.getData());
        Map data = message.getData();
        PushManager.parsePushNotification(getBaseContext(), data, new ObjectResultCallback<Push>() {
            @Override
            public void onSuccess(Push push) {
                Logger.setTag(_TAG).i("Received Flybits Push: " + push.toString());
                setNotification(getBaseContext(), push.getTitle(), push.getMessage());

                Intent intentCustom = new Intent(ACTION_PUSH_RECEIVED_FLYBITS);
                intentCustom.putExtra(ACTION_PUSH_RECEIVED_FLYBITS, push);
                LocalBroadcastManager.getInstance(getBaseContext()).sendBroadcast(intentCustom);
            }

            @Override
            public void onException(FlybitsException e) {
                if (e instanceof FlybitsPushException) {
                    if (message.getNotification() != null) {
                        Logger.setTag(_TAG).i("Received FCM Push: " + message.getNotification().getBody());
                        setNotification(getBaseContext(), message.getNotification().getTitle(), message.getNotification().getBody());
                    }

                    Intent intentCustom = new Intent(ACTION_PUSH_RECEIVED_FCM);
                    intentCustom.putExtra(EXTRA_PUSH_NOTIFICATION, message);
                    LocalBroadcastManager.getInstance(getBaseContext()).sendBroadcast(intentCustom);
                }
            }
        });
    }

    private void setNotification(Context context, String title, String body){
        NotificationManager mNotificationManager = (NotificationManager)
                context.getSystemService(Context.NOTIFICATION_SERVICE);

        boolean isTitlePresent = !TextUtils.isEmpty(title);
        //Incase null to avoid crash
        if (body == null) {
            body = "";
        }

        long[] vibration = new long[1];
        vibration[0] = 100L;

        NotificationCompat.BigTextStyle bigText = new NotificationCompat.BigTextStyle();
        bigText.bigText(body);

        String txtTitle = (isTitlePresent) ? title : "Received Notification";
        bigText.setBigContentTitle(txtTitle);

        NotificationCompat.Builder mBuilder =
                new NotificationCompat.Builder(context, NOTIFICATION_CHANNEL_FLYBITS)
                        .setContentText(body)
                        .setSmallIcon(getResource())
                        .setVibrate(vibration)
                        .setStyle(bigText)
                        .setWhen(System.currentTimeMillis())
                        .setShowWhen(true)
                        .setAutoCancel(true);

        if (isTitlePresent) {
            mBuilder.setContentTitle(txtTitle);
        }

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
            NotificationChannel mChannel = new NotificationChannel(NOTIFICATION_CHANNEL_FLYBITS, "",
                    NotificationManager.IMPORTANCE_DEFAULT);

            // Configure the notification channel.
            mChannel.enableLights(true);
            mChannel.enableVibration(true);
            mNotificationManager.createNotificationChannel(mChannel);
        }

        int num = (int) System.currentTimeMillis();
        mNotificationManager.notify(num, mBuilder.build());
    }

    private int getResource(){
        try {
            ComponentName myService = new ComponentName(this, this.getClass());
            Bundle bundle = getPackageManager().getServiceInfo(myService, PackageManager.GET_META_DATA).metaData;

            if (bundle.containsKey("com.flybits.push.notification.icon")) {
                return  bundle.getInt("com.flybits.push.notification.icon");
            }
        }catch (PackageManager.NameNotFoundException | NullPointerException e) {
            Logger.exception("FlybitsPushService.getResource", e);
        }
        Logger.setTag(_TAG).w("It appears that you have not set your icon's resource field within your AndroidManifest declaration of the FlybitsPushService. Please visit https://devportal.flybits.com/#/documentation/android/push/push-notifications-receiving for more details.");
        return R.mipmap.ic_flybits_notification;
    }
}
